==> central-repository-3.60.0.zip: ej/library/eclasspath/httpclient/1.3.0/CHANGELOG-1.3.0.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 1.3.0 - 2019-03-01

### Changed

  - Use dependency with ej.library.eclasspath.collections.
  - Use build type 4.+.
  - Use MMM.
  

## 1.2.2 - 2016-04-08

### Added

  - Initial public revision.

## 1.2.0 - 2016-02-03

### Added

  - Automatically load the internal handler when this artifact is fetched

## 1.1.0 - 2015-12-08 

### Added

  - Speed optimizations by removing internal MeteredStream wrapper

## 1.0.0 - 2015-07-16 

### Added

  - Initial version.
  
  
---  
_Markdown_
_Copyright 2015-2019 MicroEJ Corp. - EDC compliance and optimizations._
_DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER._
_ _
_This code is free software; you can redistribute it and/or modify it_
_under the terms of the GNU General Public License version 2 only, as_
_published by the Free Software Foundation._
_ _
_This code is distributed in the hope that it will be useful, but WITHOUT_
_ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or_
_FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License_
_version 2 for more details (a copy is included in the LICENSE file that_
_accompanied this code)._
_ _
_You should have received a copy of the GNU General Public License version_
_2 along with this work; if not, write to the Free Software Foundation,_
_Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA._
_ _
_Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA_
_or visit www.oracle.com if you need additional information or have any_
_questions._

==> central-repository-3.63.0.zip: ej/library/eclasspath/httpclient/1.5.0/CHANGELOG-1.5.0.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 1.5.0 - 2021-01-15

### Changed

 - Marked APIs with annotations for Null Analysis.
 - Updated implementation code to comply with Null Analysis.

## 1.4.0 - 2020-03-20

### Added

  - Add possibility to set the buffered size using BON constants.
  
## 1.3.0 - 2019-03-01

### Changed

  - Use dependency with ej.library.eclasspath.collections.
  - Use build type 4.+.
  - Use MMM.
  

## 1.2.2 - 2016-04-08

### Added

  - Initial public revision.

## 1.2.0 - 2016-02-03

### Added

  - Automatically load the internal handler when this artifact is fetched

## 1.1.0 - 2015-12-08 

### Added

  - Speed optimizations by removing internal MeteredStream wrapper

## 1.0.0 - 2015-07-16 

### Added

  - Initial version.
  
  
---  
_Markdown_  
_Copyright 2015-2021 MicroEJ Corp. - EDC compliance and optimizations._  
_DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER._  
_ _  
_This code is free software; you can redistribute it and/or modify it_  
_under the terms of the GNU General Public License version 2 only, as_  
_published by the Free Software Foundation._  
_ _  
_This code is distributed in the hope that it will be useful, but WITHOUT_  
_ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or_  
_FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License_  
_version 2 for more details (a copy is included in the LICENSE file that_  
_accompanied this code)._  
_ _  
_You should have received a copy of the GNU General Public License version_  
_2 along with this work; if not, write to the Free Software Foundation,_  
_Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA._  
_ _  
_Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA_  
_or visit www.oracle.com if you need additional information or have any_  
_questions._
